# About
This repo was created to provide a convenient way to install GDEM0213E26LT 2.13" e-paper library for Raspberry Pi.
The original code is provided by [Waveshare GitHub](https://github.com/soonuse/epd-library-python).
